<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }


echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";


print("</head>\n");
print("<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>\n");

print("<TABLE border=0 bgcolor=FFA500 cellspacing=3 cellpadding=0 width=100%>\n");
print("<tr><td align=left><font color=ffffff><b>顼ܺ</b></font></td></tr>\n");
print("</table>\n");


$ncol1 = "bgcolor=#f0f0d2";
$ncol2 = "bgcolor=#d2f0f0";
$gno = enco($_GET["KEY"]);

echo "<pre>";

print($version_name);
print("\n");
print(date("Y m d g i s A"));
print("\n");
echo "Priority 1 = <font color=red>Red,</font> 2 = <font color=magenta>Magenta,</font> 3 = <font color=green>Green,</font>";

$conn = db_connect();
if(!$conn){
   echo "not connection!<br>";
   exit;
   }

$result = db_query($conn, "select * from errlog where uno='$gno'");
if(!$result){
   print("bud query\n");
   exit;
   }

$num = db_num_rows($result);
if($num <= 0){
   print("no data\n");
   exit;
   }

print("\n\n");

echo "<TABLE border=0  WIDTH=70% height=2% BGCOLOR=$my_bocolor>";

while($s < $num){
   $CIP = enco_rtrim(db_fetch_Result($result, $s, cip));
   $CNAME = enco_rtrim(db_fetch_Result($result, $s, cname));
   $MONITOR = enco_rtrim(db_fetch_Result($result, $s, monitor));
   $UCT = enco_rtrim(db_fetch_Result($result, $s, uct));
   $YE = enco_rtrim(db_fetch_Result($result, $s, ye));
   $MO = enco_rtrim(db_fetch_Result($result, $s, mo));
   $DA = enco_rtrim(db_fetch_Result($result, $s, da));
   $HA = enco_rtrim(db_fetch_Result($result, $s, ha));
   $MI = enco_rtrim(db_fetch_Result($result, $s, mi));
   $SE = enco_rtrim(db_fetch_Result($result, $s, se));
   $SIGN = enco_rtrim(db_fetch_Result($result, $s, sign));
   $PROTO = enco_rtrim(db_fetch_Result($result, $s, proto));
   $COM = enco_rtrim(db_fetch_Result($result, $s, com));
   $CINFO = enco_rtrim(db_fetch_Result($result, $s, cinfo));
   $PORT = enco_rtrim(db_fetch_Result($result, $s, port));
   $WTIME = enco_rtrim(db_fetch_Result($result, $s, wtime));
   $PINFO = enco_rtrim(db_fetch_Result($result, $s, pinfo));
   $ERRDATA = enco_rtrim(db_fetch_Result($result, $s, errdata));
   $PRINO = enco_rtrim(db_fetch_Result($result, $s, prino));
   $FREE1 = enco_rtrim(db_fetch_Result($result, $s, free1));
   $FREE2 = enco_rtrim(db_fetch_Result($result, $s, free2));
   $FREE3 = enco_rtrim(db_fetch_Result($result, $s, free3));
   $FREE4 = enco_rtrim(db_fetch_Result($result, $s, free4));
   $UNO = enco_rtrim(db_fetch_Result($result, $s, uno));

   if($PRINO <= 1){
      $pcol = "bgcolor=red";
      }
   if($PRINO == 2){
      $pcol = "bgcolor=magenta";
      }
   if($PRINO == 3){
      $pcol = "bgcolor=green";
      }
   if($PRINO >= 4){
      $pcol = "bgcolor=orengi";
      }

 
   echo "<tr>"; 


   if(0 == strcmp($MONITOR, "CONNECT")){
      echo "<td $pcol>$MO/$DA $HA:$MI:$SE</td><td $acol1></td>";
      echo "<td $acol2><a target=new href=$monitorwatch?CINFO=$CINFO>$PINFO</a></td>";
      echo "<td $acol1><a target=_self href=$detaile?KEY=$UNO>$MONITOR</a></td>";
      echo "<td $acol2>$ERRDATA</td><td $ncol1>NOT</td>";
      echo "<td $acol1><a target=_self href=$monitorwatch?CNAME=$CNAME>$CNAME</a></td>";
      echo "<td $acol2>NON</td>";
      }
   elseif(0 == strcmp($MONITOR, "CLOSE")){
      echo "<td $pcol>$MO/$DA $HA:$MI:$SE</td><td $bcol1></td>";
      echo "<td $bcol2><a target=new href=$monitorwatch?CINFO=$CINFO>$PINFO</a></td>";
      echo "<td $bcol1><a target=_self href=$detaile?KEY=$UNO>$MONITOR</a></td>";

      echo "<td $bcol2>$ERRDATA</td><td $ncol1>NOT</td>";
      echo "<td $bcol1><a target=_self href=$monitorwatch?CNAME=$CNAME>$CNAME</a></td>";
      echo "<td $ncol2>NON</td>";
      }
   else{
      echo "<td $pcol><a target=edit href=$monitorwatch?UNO=$FREE3>$MO/$DA $HA:$MI:$SE</a></td>";
      echo "<td $ncol1><a target=edit href=$monitorwatch?CNAME=$CNAME&MONITOR=$MONITOR&CIP=$CINFO>&&&</a></td>";
      echo "<td $ncol2><a target=_self href=$monitorwatch?CIP=$CINFO>$CINFO</a></td>";
      echo "<td $ncol1><a target=_self href=$detaile?KEY=$UNO>$MONITOR</a></td>";
      if(0 == strcmp($MONITOR, "PORT")){
         echo "<td $ncol2>$PROTO</td>";
         echo "<td $ncol1>$PORT</td>";
         echo "<td $ncol2><a target=_self href=$monitorwatch?CNAME=$CNAME>$CNAME</a></td>";
         echo "<td $ncol1><a target=self href=$monitorwatch?FREE4=$FREE4>$FREE4</a></td>";
         }
      elseif(0 == strcmp($MONITOR, "SNMP")){
         echo "<td $ncol2>$FREE1</td>";
         echo "<td $ncol1>$PROTO</td>";
         echo "<td $ncol2><a target=_self href=$monitorwatch?CNAME=$CNAME>$CNAME</a></td>";
         echo "<td $ncol1><a target=self href=$monitorwatch?FREE4=$FREE4>$FREE4</a></td>";
         }
      else{
         echo "<td $ncol2>$COM</td>";
         echo "<td $ncol1>NOT</td>";
         echo "<td $ncol2><a target=_self href=$monitorwatch?CNAME=$CNAME>$CNAME</a></td>";
         echo "<td $ncol1><a target=self href=$monitorwatch?FREE4=$FREE4>$FREE4</a></td>";
         }
      }


   echo "</tr>";
   $s++;
   }

echo"</table>";

db_free_result($result);
db_Close($conn);

echo "\n";
echo "<font color=red size=1>";
echo "ޤǤ˴¬줿ƻֹ $FREE3 Υ顼֥顼פɽʤˤ";
echo "<a target=top href=./sign_set.php?FREE3=$FREE3>";
echo "";
echo "</a>";
echo "򥯥å\n";
echo "</font>";
echo "\n\n";


if(0 == strcmp($MONITOR, "SNMP")){
   echo "<table>";
   echo "<font color=red>";
   echo "<tr><td>ƻIPURL               </td><td>=  </td><td> $CINFO </td></tr>";
   echo "<tr><td>ƻξ                  </td><td>=  </td><td> $PINFO </td></tr>";
   echo "</font>";
   echo "<tr><td>ƻ°                      </td><td>=  </td><td> $MONITOR</td></tr>";
   echo "<tr><td>顼λUCT             </td><td>=  </td><td> $UCT</td></tr>";
   echo "<tr><td>顼λlocal           </td><td>=  </td><td> $YE:$MO:$DA:$HA:$MI:$SE</td></tr>";
   echo "<tr><td>ƻˡ                </td><td>=  </td><td> $SIGN</td></tr>";
   echo "<tr><td>SNMPƻ                  </td><td>=  </td><td> $PROTO</td></tr>";
   echo "<tr><td>SNMPƻOID                   </td><td>=  </td><td> $COM</td></tr>";
   echo "<tr><td>¹Ԥ                  </td><td>=  </td><td> $WTIME</td></tr>";
   echo "<tr><td>顼ξܺ                  </td><td>=  </td><td> $ERRDATA</td></tr>";
   echo "<tr><td>δƻΥץ饤ƥ    </td><td>=  </td><td> $PRINO</td></tr>";
   echo "<tr><td>ȣ                    </td><td>=  </td><td> $FREE1</td></tr>";
   echo "<tr><td>ƻ륯饤IP            </td><td>=  </td><td> $CIP</td></tr>";
   echo "<tr><td>ƻ륯饤̾            </td><td>=  </td><td> $CNAME</td></tr>";
   echo "</table>";

   echo "\n\n";
   echo "<font color=red>";
   echo "оݤƻ뤷Ƥ륯饤Ȥ $CNAME $CIP Ǥ"; print("\n");
   echo "δƻܤϥ֥å̾ $FREE4 ˴ޤޤƤޤ"; print("\n");
   echo "</font>";
   }

elseif(0 == strcmp($MONITOR, "COMAND")){
   echo "<table>";
   echo "<font color=red>";
   echo "<tr><td>ƻIPURL               </td><td>=  </td><td> $CINFO $CNAME $CIP</td></tr>";
   echo "<tr><td>ƻξ                  </td><td>=  </td><td> $PINFO</td></tr>";
   echo "</font>";
   echo "<tr><td>ƻ°                      </td><td>=  </td><td> $MONITOR</td></tr>";
   echo "<tr><td>顼λUCT             </td><td>=  </td><td> $UCT</td></tr>";
   echo "<tr><td>顼λlocal           </td><td>=  </td><td> $YE:$MO:$DA:$HA:$MI:$SE</td></tr>";
   echo "<tr><td>ƻˡ                </td><td>=  </td><td> $SIGN</td></tr>";
   echo "<tr><td>ޥɴƻμ¹ԥޥ    </td><td>=  </td><td> $COM </td></tr>";
   echo "<tr><td>¹Ԥ                  </td><td>=  </td><td> $WTIME</td></tr>";
   echo "<tr><td>顼ξܺ                  </td><td>=  </td><td> $ERRDATA</td></tr>";
   echo "<tr><td>δƻΥץ饤ƥ    </td><td>=  </td><td> $PRINO</td></tr>";
   echo "<tr><td>ȣ                    </td><td>=  </td><td> $FREE1</td></tr>";
   echo "</table>";

   echo "\n\n";
   echo "<font color=red>";
   echo "оݤƻ뤷Ƥ륯饤ȤϤδƻ륯饤ȼȤǤ"; print("\n");
   echo "δƻܤϥ֥å̾ $FREE4 ˴ޤޤƤޤ"; print("\n");
   echo "</font>";
   }

elseif(0 == strcmp($MONITOR, "PORT") && 0 != strcmp($PROTO, "DHW") && 0 != strcmp($PROTO, "MYSQL")){
   echo "<table>";
   echo "<font color=red>";
   echo "<tr><td>ƻIPURL               </td><td>=   </td><td> $CINFO</td></tr>";
   echo "<tr><td>ƻξ                  </td><td>=   </td><td> $PINFO</td></tr>";
   echo "</font>";
   echo "<tr><td>ƻ°                      </td><td>=   </td><td> $MONITOR</td></tr>";
   echo "<tr><td>顼λUCT             </td><td>=   </td><td> $UCT</td></tr>";
   echo "<tr><td>顼λlocal           </td><td>=   </td><td> $YE:$MO:$DA:$HA:$MI:$SE</td></tr>";
   echo "<tr><td>ƻˡ                </td><td>=   </td><td> $SIGN</td></tr>";
   echo "<tr><td>ݡȴƻΥץȥ        </td><td>=   </td><td> $PROTO</td></tr>";
   echo "<tr><td>ݡȴƻδƻݡ        </td><td>=   </td><td>$PORT</td></tr>";
   echo "<tr><td>¹Ԥ                  </td><td>=   </td><td>$WTIME</td></tr>";
   echo "<tr><td>顼ξܺ                  </td><td>=   </td><td>$ERRDATA</td></tr>";
   echo "<tr><td>δƻΥץ饤ƥ    </td><td>=   </td><td>$PRINO</td></tr>";
   echo "<tr><td>ȣ                    </td><td>=   </td><td>$FREE1</td></tr>";
   echo "<tr><td>ƻ륯饤IP            </td><td>=   </td><td>$CIP</td></tr>";
   echo "<tr><td>ƻ륯饤̾            </td><td>=   </td><td>$CNAME</td></tr>";
   echo "</table>";

   echo "\n\n";
   echo "<font color=red>";
   echo "оݤƻ뤷Ƥ륯饤Ȥ $CNAME $CIP Ǥ"; print("\n");
   echo "δƻܤϥ֥å̾ $FREE4 ˴ޤޤƤޤ"; print("\n");
   echo "</font>";
   }

elseif(0 == strcmp($MONITOR, "PORT") && 0 == strcmp($PROTO, "DHW")){
   echo "<table>";
   echo "<font color=red>";
   echo "<tr><td>DHWƻIPURL            </td><td>=   </td><td>$CINFO</td></tr>";
   echo "<tr><td>ƻξ                  </td><td>=   </td><td>$PINFO</td></tr>";
   echo "</font>";
   echo "<tr><td>ƻ°                      </td><td>=   </td><td>$MONITOR</td></tr>";
   echo "<tr><td>顼λUCT             </td><td>=   </td><td>$UCT</td></tr>"; print("\n");
   echo "<tr><td>顼λlocal           </td><td>=   </td><td>$YE:$MO:$DA:$HA:$MI:$SE</td></tr>";
   echo "<tr><td>ƻˡ                </td><td>=   </td><td>$SIGN</td></tr>";
   echo "<tr><td>DHWƻδƻݡ           </td><td>=   </td><td>$PORT</td></tr>";
   echo "<tr><td>¹Ԥ                  </td><td>=   </td><td>$WTIME</td></tr>";
   echo "<tr><td>DHW¹ԥޥ               </td><td>=   </td><td>$COM</td></tr>";
   echo "<tr><td>DHW顼ξܺ               </td><td>=   </td><td>$ERRDATA</td></tr>";
   echo "<tr><td>δƻΥץ饤ƥ    </td><td>=   </td><td>$PRINO</td></tr>";
   echo "<tr><td>ȣ                    </td><td>=   </td><td>$FREE1</td></tr>";
   echo "<tr><td>ƻ륯饤IP            </td><td>=   </td><td>$CIP</td></tr>";
   echo "<tr><td>ƻ륯饤̾            </td><td>=   </td><td>$CNAME</td><tr>";
   echo "</table>";

   echo "\n\n";
   echo "<font color=red>";
   echo "оݤƻ뤷Ƥ륯饤Ȥ $CNAME $CIP Ǥ"; print("\n");
   echo "δƻܤϥ֥å̾ $FREE4 ˴ޤޤƤޤ"; print("\n");
   echo "</font>";
   }


elseif(0 == strcmp($MONITOR, "PORT") && 0 == strcmp($PROTO, "MYSQL")){
   echo "<table>";
   echo "<font color=red>";
   echo "<tr><td>MYSQL³                 </td><td>=   </td><td>$CINFO</td></tr>";
   echo "<tr><td>ƻξ                  </td><td>=   </td><td>$PINFO</td></tr>";
   echo "</font>";
   echo "<tr><td>ƻ°                      </td><td>=   </td><td>$MONITOR</td></tr>";
   echo "<tr><td>顼λUCT             </td><td>=   </td><td>$UCT</td></tr>"; print("\n");
   echo "<tr><td>顼λlocal           </td><td>=   </td><td>$YE:$MO:$DA:$HA:$MI:$SE</td></tr>";
   echo "<tr><td>ƻˡ                </td><td>=   </td><td>$SIGN</td></tr>";
   echo "<tr><td>MYSQLƻδƻݡ         </td><td>=   </td><td>$PORT</td></tr>";
   echo "<tr><td>¹Ԥ                  </td><td>=   </td><td>$WTIME</td></tr>";
   echo "<tr><td>MYSQL꡼                 </td><td>=   </td><td>$COM</td></tr>";
   echo "<tr><td>MYSQL顼ξܺ               </td><td>=   </td><td>$ERRDATA</td></tr>";
   echo "<tr><td>δƻΥץ饤ƥ    </td><td>=   </td><td>$PRINO</td></tr>";
   echo "<tr><td>ȣ                    </td><td>=   </td><td>$FREE1</td></tr>";
   echo "<tr><td>ƻ륯饤IP            </td><td>=   </td><td>$CIP</td></tr>";
   echo "<tr><td>ƻ륯饤̾            </td><td>=   </td><td>$CNAME</td><tr>";
   echo "</table>";

   echo "\n\n";
   echo "<font color=red>";
   echo "оݤƻ뤷Ƥ륯饤Ȥ $CNAME $CIP Ǥ"; print("\n");
   echo "δƻܤϥ֥å̾ $FREE4 ˴ޤޤƤޤ"; print("\n");
   echo "</font>";
   }



else{
   echo "<table>";
   echo "<font color=red>";
   echo "<tr><td>ƻIPURL               </td><td>=   </td><td>$CINFO</td></tr>";
   echo "<tr><td>ƻξ                  </td><td>=   </td><td>$PINFO</td></tr>";
   echo "</font>";
   echo "<tr><td>ƻ°                      </td><td>=   </td><td>$MONITOR</td></tr>";
   echo "<tr><td>顼λUCT             </td><td>=   </td><td>$UCT</td></tr>";
   echo "<tr><td>顼λlocal           </td><td>=   </td><td>$YE:$MO:$DA:$HA:$MI:$SE</td></tr>";
   echo "<tr><td>ƻˡ                </td><td>=   </td><td>$SIGN</td></tr>";
   echo "<tr><td>ݡȴƻΥץȥ        </td><td>=   </td><td>$PROTO</td></tr>";
   echo "<tr><td>ޥɴƻμ¹ԥޥ    </td><td>=   </td><td>$COM</td></tr>";
   echo "<tr><td>ݡȴƻδƻݡ        </td><td>=   </td><td>$PORT</td></tr>";
   echo "<tr><td>¹Ԥ                  </td><td>=   </td><td>$WTIME</td></tr>";
   echo "<tr><td>顼ξܺ                  </td><td>=   </td><td>$ERRDATA</td></tr>";
   echo "<tr><td>δƻΥץ饤ƥ    </td><td>=   </td><td>$PRINO</td></tr>";
   echo "<tr><td>ȣ                    </td><td>=   </td><td>$FREE1</td></tr>";
   echo "<tr><td>ƻ륯饤IP            </td><td>=   </td><td>$CIP</td></tr>";
   echo "<tr><td>ƻ륯饤̾            </td><td>=   </td><td>$CNAME</td></tr>";
   echo "</table>";

   echo "\n\n";
   echo "<font color=red>";
   if(0 == strcmp($MONITOR, "CONNECT")){
      echo "ƻ륯饤̾ $CNAME $CIP ³ޤ\n";
      }
   elseif(0 == strcmp($MONITOR, "CLOSE")){
      echo "ƻ륯饤̾ $CNAME $CIP Ȥ³Ǥޤ\n";
      }
   else{
      echo "оݤƻ뤷Ƥ륯饤Ȥ $CNAME $CIP Ǥ\n";
      echo "δƻܤϥ֥å̾ $FREE4 ˴ޤޤƤޤ"; print("\n");
      }
   echo "</font>";
   }


echo "\n\n";


echo "ƻ뤵ƤIPɥ쥹";
print($CINFO);
echo "";
echo "\n\n";

echo "Υ顼Τƻ륯饤";
print($CNAME);
echo "";
echo "\n\n";

?>

</pre>
</body>
</html>


